==> file-management-1.2-sources.jar: org/apache/maven/shared/model/fileset/FileSet.java <==
/*
 * $Id$
 */

package org.apache.maven.shared.model.fileset;

  //---------------------------------/
 //- Imported classes and packages -/
//---------------------------------/

import java.util.Date;

/**
 * 
 *         Defines the rules for matching and working with files in
 * a given base directory.
 *       
 * 
 * @version $Revision$ $Date$
 */
public class FileSet extends SetBase 
implements java.io.Serializable
{


      //--------------------------/
     //- Class/Member Variables -/
    //--------------------------/

    /**
     * Field directory
     */
    private String directory;

    /**
     * Field lineEnding
     */
    private String lineEnding;


      //-----------/
     //- Methods -/
    //-----------/

    /**
     * Get 
     *             Absolute or relative from the module's
     * directory.  For
     *             example, "src/main/bin" would select this
     * subdirectory
     *             of the project in which this dependency is
     * defined.
     *           
     */
    public String getDirectory()
    {
        return this.directory;
    } //-- String getDirectory() 

    /**
     * Get 
     *             
     *             Controls the line-endings of files in this
     * fileSet.
     *             <br/>
     *             Valid values:
     *             <ul>
     *               <li><b>"keep"</b> - Preserve all line
     * endings</li>
     *               <li><b>"unix"</b> - Use Unix-style line
     * endings</li>
     *               <li><b>"lf"</b> - Use a single line-feed line
     * endings</li>
     *               <li><b>"dos"</b> - Use DOS-style line
     * endings</li>
     *               <li><b>"crlf"</b> - Use Carraige-return,
     * line-feed line endings</li>
     *             </ul>
     *             
     *           
     */
    public String getLineEnding()
    {
        return this.lineEnding;
    } //-- String getLineEnding() 

    /**
     * Set 
     *             Absolute or relative from the module's
     * directory.  For
     *             example, "src/main/bin" would select this
     * subdirectory
     *             of the project in which this dependency is
     * defined.
     *           
     * 
     * @param directory
     */
    public void setDirectory(String directory)
    {
        this.directory = directory;
    } //-- void setDirectory(String) 

    /**
     * Set 
     *             
     *             Controls the line-endings of files in this
     * fileSet.
     *             <br/>
     *             Valid values:
     *             <ul>
     *               <li><b>"keep"</b> - Preserve all line
     * endings</li>
     *               <li><b>"unix"</b> - Use Unix-style line
     * endings</li>
     *               <li><b>"lf"</b> - Use a single line-feed line
     * endings</li>
     *               <li><b>"dos"</b> - Use DOS-style line
     * endings</li>
     *               <li><b>"crlf"</b> - Use Carraige-return,
     * line-feed line endings</li>
     *             </ul>
     *             
     *           
     * 
     * @param lineEnding
     */
    public void setLineEnding(String lineEnding)
    {
        this.lineEnding = lineEnding;
    } //-- void setLineEnding(String) 


    private String modelEncoding = "UTF-8";

    public void setModelEncoding( String modelEncoding )
    {
        this.modelEncoding = modelEncoding;
    }

    public String getModelEncoding()
    {
        return modelEncoding;
    }
}

==> file-management-1.2.1-sources.jar: org/apache/maven/shared/model/fileset/FileSet.java <==
/*
 * $Id$
 */

package org.apache.maven.shared.model.fileset;

  //---------------------------------/
 //- Imported classes and packages -/
//---------------------------------/

import java.util.Date;

/**
 * 
 *         Defines the rules for matching and working with files in
 * a given base directory.
 *       
 * 
 * @version $Revision$ $Date$
 */
public class FileSet extends SetBase 
implements java.io.Serializable
{


      //--------------------------/
     //- Class/Member Variables -/
    //--------------------------/

    /**
     * 
     *             Absolute or relative from the module's
     * directory.  For
     *             example, "src/main/bin" would select this
     * subdirectory
     *             of the project in which this dependency is
     * defined.
     *           
     */
    private String directory;

    /**
     * 
     *             
     *             Controls the line-endings of files in this
     * fileSet.
     *             <br/>
     *             Valid values:
     *             <ul>
     *               <li><b>"keep"</b> - Preserve all line
     * endings</li>
     *               <li><b>"unix"</b> - Use Unix-style line
     * endings</li>
     *               <li><b>"lf"</b> - Use a single line-feed line
     * endings</li>
     *               <li><b>"dos"</b> - Use DOS-style line
     * endings</li>
     *               <li><b>"crlf"</b> - Use Carraige-return,
     * line-feed line endings</li>
     *             </ul>
     *             
     *           
     */
    private String lineEnding;


      //-----------/
     //- Methods -/
    //-----------/

    /**
     * Get 
     *             Absolute or relative from the module's
     * directory.  For
     *             example, "src/main/bin" would select this
     * subdirectory
     *             of the project in which this dependency is
     * defined.
     *           
     * 
     * @return String
     */
    public String getDirectory()
    {
        return this.directory;
    } //-- String getDirectory() 

    /**
     * Get 
     *             
     *             Controls the line-endings of files in this
     * fileSet.
     *             <br/>
     *             Valid values:
     *             <ul>
     *               <li><b>"keep"</b> - Preserve all line
     * endings</li>
     *               <li><b>"unix"</b> - Use Unix-style line
     * endings</li>
     *               <li><b>"lf"</b> - Use a single line-feed line
     * endings</li>
     *               <li><b>"dos"</b> - Use DOS-style line
     * endings</li>
     *               <li><b>"crlf"</b> - Use Carraige-return,
     * line-feed line endings</li>
     *             </ul>
     *             
     *           
     * 
     * @return String
     */
    public String getLineEnding()
    {
        return this.lineEnding;
    } //-- String getLineEnding() 

    /**
     * Set 
     *             Absolute or relative from the module's
     * directory.  For
     *             example, "src/main/bin" would select this
     * subdirectory
     *             of the project in which this dependency is
     * defined.
     *           
     * 
     * @param directory
     */
    public void setDirectory(String directory)
    {
        this.directory = directory;
    } //-- void setDirectory(String) 

    /**
     * Set 
     *             
     *             Controls the line-endings of files in this
     * fileSet.
     *             <br/>
     *             Valid values:
     *             <ul>
     *               <li><b>"keep"</b> - Preserve all line
     * endings</li>
     *               <li><b>"unix"</b> - Use Unix-style line
     * endings</li>
     *               <li><b>"lf"</b> - Use a single line-feed line
     * endings</li>
     *               <li><b>"dos"</b> - Use DOS-style line
     * endings</li>
     *               <li><b>"crlf"</b> - Use Carraige-return,
     * line-feed line endings</li>
     *             </ul>
     *             
     *           
     * 
     * @param lineEnding
     */
    public void setLineEnding(String lineEnding)
    {
        this.lineEnding = lineEnding;
    } //-- void setLineEnding(String) 


    private String modelEncoding = "UTF-8";

    /**
     * Set an encoding used for reading/writing the model.
     *
     * @param modelEncoding the encoding used when reading/writing the model.
     */
    public void setModelEncoding( String modelEncoding )
    {
        this.modelEncoding = modelEncoding;
    }

    /**
     * @return the current encoding used when reading/writing this model.
     */
    public String getModelEncoding()
    {
        return modelEncoding;
    }
}
